==> rust-web-sys_0.3.60.orig.tar.gz: web-sys-0.3.60/src/features/gen_gpu_color_write.rs <==
#[cfg(web_sys_unstable_apis)]
#[doc = ""]
#[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
#[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
pub mod gpu_color_write {
    #![allow(unused_imports)]
    use super::super::*;
    use wasm_bindgen::prelude::*;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.RED` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const RED: u32 = 1u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.GREEN` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const GREEN: u32 = 2u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.BLUE` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const BLUE: u32 = 4u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.ALPHA` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const ALPHA: u32 = 8u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.ALL` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://rustwasm.github.io/docs/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const ALL: u32 = 15u64 as u32;
}

==> rust-web-sys_0.3.81.orig.tar.gz: web-sys-0.3.81/src/features/gen_gpu_color_write.rs <==
#[cfg(web_sys_unstable_apis)]
#[doc = ""]
#[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
#[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
pub mod gpu_color_write {
    #![allow(unused_imports)]
    #![allow(clippy::all)]
    use super::super::*;
    use wasm_bindgen::prelude::*;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.RED` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const RED: u32 = 1u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.GREEN` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const GREEN: u32 = 2u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.BLUE` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const BLUE: u32 = 4u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.ALPHA` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const ALPHA: u32 = 8u64 as u32;
    #[cfg(web_sys_unstable_apis)]
    #[doc = "The `GPUColorWrite.ALL` const."]
    #[doc = ""]
    #[doc = "*This API requires the following crate features to be activated: `gpu_color_write`*"]
    #[doc = ""]
    #[doc = "*This API is unstable and requires `--cfg=web_sys_unstable_apis` to be activated, as"]
    #[doc = "[described in the `wasm-bindgen` guide](https://wasm-bindgen.github.io/wasm-bindgen/web-sys/unstable-apis.html)*"]
    pub const ALL: u32 = 15u64 as u32;
}
